pub struct BalanceAlertLayer { /* private fields */ }Implementations
Sourceimpl BalanceAlertLayer
A ProviderLayer that can be added to an alloy Provider
to log warnings and errors when the balance of a given address
falls below certain thresholds.
impl BalanceAlertLayer
A ProviderLayer that can be added to an alloy Provider to log warnings and errors when the balance of a given address falls below certain thresholds.
This checks the balance after every transaction sent via send_transaction and errors, warns or trace logs accordingly
Examples
ⓘ
let provider = ProviderBuilder::new()
.layer(BalanceAlertLayer::new(BalanceAlertConfig {
watch_address: wallet.default_signer().address(),
warn_threshold: parse_ether("0.1")?,
error_threshold: parse_ether("0.1")?,
}));pub fn new(config: BalanceAlertConfig) -> Self